import sys
import unittest

import smscx_client
from smscx_client.model.data_summary import DataSummary
globals()['DataSummary'] = DataSummary
from smscx_client.model.reports_summary_country_response_data_value import ReportsSummaryCountryResponseDataValue


class TestReportsSummaryCountryResponseDataValue(unittest.TestCase):
    """ReportsSummaryCountryResponseDataValue unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testReportsSummaryCountryResponseDataValue(self):
        """Test ReportsSummaryCountryResponseDataValue"""
        # FIXME: construct object with mandatory attributes with example values
        # model = ReportsSummaryCountryResponseDataValue()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
