import sys
import unittest

import smscx_client
from smscx_client.model.country_price_obj1 import CountryPriceObj1


class TestCountryPriceObj1(unittest.TestCase):
    """CountryPriceObj1 unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testCountryPriceObj1(self):
        """Test CountryPriceObj1"""
        # FIXME: construct object with mandatory attributes with example values
        # model = CountryPriceObj1()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
