import sys
import unittest

import smscx_client
from smscx_client.model.reports_summary_source_response_data_value import ReportsSummarySourceResponseDataValue
globals()['ReportsSummarySourceResponseDataValue'] = ReportsSummarySourceResponseDataValue
from smscx_client.model.reports_summary_source_response import ReportsSummarySourceResponse


class TestReportsSummarySourceResponse(unittest.TestCase):
    """ReportsSummarySourceResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testReportsSummarySourceResponse(self):
        """Test ReportsSummarySourceResponse"""
        # FIXME: construct object with mandatory attributes with example values
        # model = ReportsSummarySourceResponse()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
