import sys
import unittest

import smscx_client
from smscx_client.model.account_balance import AccountBalance


class TestAccountBalance(unittest.TestCase):
    """AccountBalance unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testAccountBalance(self):
        """Test AccountBalance"""
        # FIXME: construct object with mandatory attributes with example values
        # model = AccountBalance()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
