import unittest

import smscx_client
from smscx_client.api.shortlinks_api import ShortlinksApi  # noqa: E501


class TestShortlinksApi(unittest.TestCase):
    """ShortlinksApi unit test stubs"""

    def setUp(self):
        self.api = ShortlinksApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_shortlink(self):
        """Test case for create_shortlink

        Create shortlink  # noqa: E501
        """
        pass

    def test_delete_shortlink(self):
        """Test case for delete_shortlink

        Delete shortlink  # noqa: E501
        """
        pass

    def test_export_shortlink_hits_to_csv(self):
        """Test case for export_shortlink_hits_to_csv

        Export shortlink hits to CSV  # noqa: E501
        """
        pass

    def test_export_shortlink_hits_to_xlsx(self):
        """Test case for export_shortlink_hits_to_xlsx

        Export shortlink hits to XLSX  # noqa: E501
        """
        pass

    def test_get_shortlink_hits(self):
        """Test case for get_shortlink_hits

        Get shortlink hits  # noqa: E501
        """
        pass

    def test_get_shortlinks_list(self):
        """Test case for get_shortlinks_list

        Get shortlinks list  # noqa: E501
        """
        pass

    def test_update_shortlink(self):
        """Test case for update_shortlink

        Update shortlink  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
