import sys
import unittest

import smscx_client
from smscx_client.model.info_groups_add_contacts_response import InfoGroupsAddContactsResponse
globals()['InfoGroupsAddContactsResponse'] = InfoGroupsAddContactsResponse
from smscx_client.model.add_contacts_to_group_response import AddContactsToGroupResponse


class TestAddContactsToGroupResponse(unittest.TestCase):
    """AddContactsToGroupResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testAddContactsToGroupResponse(self):
        """Test AddContactsToGroupResponse"""
        # FIXME: construct object with mandatory attributes with example values
        # model = AddContactsToGroupResponse()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
