import sys
import unittest

import smscx_client
from smscx_client.model.viber_whatsapp_pricing import ViberWhatsappPricing
globals()['ViberWhatsappPricing'] = ViberWhatsappPricing
from smscx_client.model.pricing_viber_whatsapp_response import PricingViberWhatsappResponse


class TestPricingViberWhatsappResponse(unittest.TestCase):
    """PricingViberWhatsappResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testPricingViberWhatsappResponse(self):
        """Test PricingViberWhatsappResponse"""
        # FIXME: construct object with mandatory attributes with example values
        # model = PricingViberWhatsappResponse()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
