import sys
import unittest

import smscx_client
from smscx_client.model.info_shortlink_detail import InfoShortlinkDetail


class TestInfoShortlinkDetail(unittest.TestCase):
    """InfoShortlinkDetail unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testInfoShortlinkDetail(self):
        """Test InfoShortlinkDetail"""
        # FIXME: construct object with mandatory attributes with example values
        # model = InfoShortlinkDetail()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
