import unittest

import smscx_client
from smscx_client.api.templates_api import TemplatesApi  # noqa: E501


class TestTemplatesApi(unittest.TestCase):
    """TemplatesApi unit test stubs"""

    def setUp(self):
        self.api = TemplatesApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_template(self):
        """Test case for create_template

        Create template  # noqa: E501
        """
        pass

    def test_delete_template(self):
        """Test case for delete_template

        Delete template  # noqa: E501
        """
        pass

    def test_get_template(self):
        """Test case for get_template

        Get template  # noqa: E501
        """
        pass

    def test_get_templates_list(self):
        """Test case for get_templates_list

        Get templates list  # noqa: E501
        """
        pass

    def test_update_template(self):
        """Test case for update_template

        Update template  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
