import sys
import unittest

import smscx_client
from smscx_client.model.attachments import Attachments


class TestAttachments(unittest.TestCase):
    """Attachments unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testAttachments(self):
        """Test Attachments"""
        # FIXME: construct object with mandatory attributes with example values
        # model = Attachments()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
