import sys
import unittest

import smscx_client
from smscx_client.model.reports_summary_delivery_response_data_value import ReportsSummaryDeliveryResponseDataValue
globals()['ReportsSummaryDeliveryResponseDataValue'] = ReportsSummaryDeliveryResponseDataValue
from smscx_client.model.reports_summary_delivery_response import ReportsSummaryDeliveryResponse


class TestReportsSummaryDeliveryResponse(unittest.TestCase):
    """ReportsSummaryDeliveryResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testReportsSummaryDeliveryResponse(self):
        """Test ReportsSummaryDeliveryResponse"""
        # FIXME: construct object with mandatory attributes with example values
        # model = ReportsSummaryDeliveryResponse()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
