import sys
import unittest

import smscx_client
from smscx_client.model.data_number_validate import DataNumberValidate


class TestDataNumberValidate(unittest.TestCase):
    """DataNumberValidate unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testDataNumberValidate(self):
        """Test DataNumberValidate"""
        # FIXME: construct object with mandatory attributes with example values
        # model = DataNumberValidate()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
