import sys
import unittest

import smscx_client
from smscx_client.model.reports_summary_channel_response_data_value import ReportsSummaryChannelResponseDataValue
globals()['ReportsSummaryChannelResponseDataValue'] = ReportsSummaryChannelResponseDataValue
from smscx_client.model.reports_summary_channel_response import ReportsSummaryChannelResponse


class TestReportsSummaryChannelResponse(unittest.TestCase):
    """ReportsSummaryChannelResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testReportsSummaryChannelResponse(self):
        """Test ReportsSummaryChannelResponse"""
        # FIXME: construct object with mandatory attributes with example values
        # model = ReportsSummaryChannelResponse()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
