import sys
import unittest

import smscx_client
from smscx_client.model.group_add import GroupAdd
globals()['GroupAdd'] = GroupAdd
from smscx_client.model.add_contacts_to_group_with_fields_request import AddContactsToGroupWithFieldsRequest


class TestAddContactsToGroupWithFieldsRequest(unittest.TestCase):
    """AddContactsToGroupWithFieldsRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testAddContactsToGroupWithFieldsRequest(self):
        """Test AddContactsToGroupWithFieldsRequest"""
        # FIXME: construct object with mandatory attributes with example values
        # model = AddContactsToGroupWithFieldsRequest()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
