import sys
import unittest

import smscx_client
from smscx_client.model.data_receive_sms import DataReceiveSms


class TestDataReceiveSms(unittest.TestCase):
    """DataReceiveSms unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testDataReceiveSms(self):
        """Test DataReceiveSms"""
        # FIXME: construct object with mandatory attributes with example values
        # model = DataReceiveSms()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
