import unittest

import smscx_client
from smscx_client.api.originators_api import OriginatorsApi  # noqa: E501


class TestOriginatorsApi(unittest.TestCase):
    """OriginatorsApi unit test stubs"""

    def setUp(self):
        self.api = OriginatorsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_originator(self):
        """Test case for create_originator

        Create new originator  # noqa: E501
        """
        pass

    def test_delete_originator(self):
        """Test case for delete_originator

        Delete originator  # noqa: E501
        """
        pass

    def test_get_originators_list(self):
        """Test case for get_originators_list

        Get originators list  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
